# This file was automatically generated by SWIG (http://www.swig.org).
# Version 2.0.10
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.



from sys import version_info
if version_info >= (2,6,0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_shm', [dirname(__file__)])
        except ImportError:
            import _shm
            return _shm
        if fp is not None:
            try:
                _mod = imp.load_module('_shm', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _shm = swig_import_helper()
    del swig_import_helper
else:
    import _shm
del version_info
try:
    _swig_property = property
except NameError:
    pass # Python < 2.2 doesn't have 'property'.
def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "thisown"): return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    if (name == "thisown"): return self.this.own()
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError(name)

def _swig_repr(self):
    try: strthis = "proxy of " + self.this.__repr__()
    except: strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0



def shm_get():
  return _shm.shm_get()
shm_get = _shm.shm_get

def get_fix_time(*args):
  return _shm.get_fix_time(*args)
get_fix_time = _shm.get_fix_time

def get_fix_mode(*args):
  return _shm.get_fix_mode(*args)
get_fix_mode = _shm.get_fix_mode

def get_fix_ept(*args):
  return _shm.get_fix_ept(*args)
get_fix_ept = _shm.get_fix_ept

def get_fix_latitude(*args):
  return _shm.get_fix_latitude(*args)
get_fix_latitude = _shm.get_fix_latitude

def get_fix_epy(*args):
  return _shm.get_fix_epy(*args)
get_fix_epy = _shm.get_fix_epy

def get_fix_longitude(*args):
  return _shm.get_fix_longitude(*args)
get_fix_longitude = _shm.get_fix_longitude

def get_fix_epx(*args):
  return _shm.get_fix_epx(*args)
get_fix_epx = _shm.get_fix_epx

def get_fix_altitude(*args):
  return _shm.get_fix_altitude(*args)
get_fix_altitude = _shm.get_fix_altitude

def get_fix_epv(*args):
  return _shm.get_fix_epv(*args)
get_fix_epv = _shm.get_fix_epv

def get_fix_track(*args):
  return _shm.get_fix_track(*args)
get_fix_track = _shm.get_fix_track

def get_fix_epd(*args):
  return _shm.get_fix_epd(*args)
get_fix_epd = _shm.get_fix_epd

def get_fix_speed(*args):
  return _shm.get_fix_speed(*args)
get_fix_speed = _shm.get_fix_speed

def get_fix_eps(*args):
  return _shm.get_fix_eps(*args)
get_fix_eps = _shm.get_fix_eps

def get_fix_climb(*args):
  return _shm.get_fix_climb(*args)
get_fix_climb = _shm.get_fix_climb

def get_fix_epc(*args):
  return _shm.get_fix_epc(*args)
get_fix_epc = _shm.get_fix_epc

def get_dop_xdop(*args):
  return _shm.get_dop_xdop(*args)
get_dop_xdop = _shm.get_dop_xdop

def get_dop_ydop(*args):
  return _shm.get_dop_ydop(*args)
get_dop_ydop = _shm.get_dop_ydop

def get_dop_pdop(*args):
  return _shm.get_dop_pdop(*args)
get_dop_pdop = _shm.get_dop_pdop

def get_dop_hdop(*args):
  return _shm.get_dop_hdop(*args)
get_dop_hdop = _shm.get_dop_hdop

def get_dop_vdop(*args):
  return _shm.get_dop_vdop(*args)
get_dop_vdop = _shm.get_dop_vdop

def get_dop_tdop(*args):
  return _shm.get_dop_tdop(*args)
get_dop_tdop = _shm.get_dop_tdop

def get_dop_gdop(*args):
  return _shm.get_dop_gdop(*args)
get_dop_gdop = _shm.get_dop_gdop

def get_online(*args):
  return _shm.get_online(*args)
get_online = _shm.get_online

def get_status(*args):
  return _shm.get_status(*args)
get_status = _shm.get_status

def get_skyview_time(*args):
  return _shm.get_skyview_time(*args)
get_skyview_time = _shm.get_skyview_time

def get_satellites_visible(*args):
  return _shm.get_satellites_visible(*args)
get_satellites_visible = _shm.get_satellites_visible

def get_satellite_ss(*args):
  return _shm.get_satellite_ss(*args)
get_satellite_ss = _shm.get_satellite_ss

def get_satellite_used(*args):
  return _shm.get_satellite_used(*args)
get_satellite_used = _shm.get_satellite_used

def get_satellite_prn(*args):
  return _shm.get_satellite_prn(*args)
get_satellite_prn = _shm.get_satellite_prn

def get_satellite_elevation(*args):
  return _shm.get_satellite_elevation(*args)
get_satellite_elevation = _shm.get_satellite_elevation

def get_satellite_azimuth(*args):
  return _shm.get_satellite_azimuth(*args)
get_satellite_azimuth = _shm.get_satellite_azimuth
MAXCHANNELS = _shm.MAXCHANNELS
# This file is compatible with both classic and new-style classes.


